This workspace provisions a linchpin multinode with multi network template. 
For example, count = 3, for each vm, it has 2 networks attached.
This template can be used to provision operating systems and architectures.

